Learn R Programming

mhurdle (version 1.0-1)

vuongtest: Vuoung test for non-nested models

Description

The Vuong test is suitable to discriminate between two non-nested models.

Usage

vuongtest(x, y, type = c("non-nested", "nested", "overlapping"), hyp = FALSE, variance = c("centered", "uncentered"), matrix = c("large", "reduced") )

Arguments

x
a first fitted model of class "mhurdle",
y
a second fitted model of class "mhurdle",
type
the kind of test to be computed,
hyp
a boolean, TRUE if one of the models is asumed to be the true model,
variance
the variance is estimated using the centered or uncentered expression,
matrix
the W matrix can be computed using the general expression large or the reduced matrix reduced (only relevant for the nested case),

Value

an object of class "htest"

References

Vuong Q.H. (1989) Likelihood ratio tests for model selection and non-nested hypothesis, Econometrica, vol.57(2), pp.307-33.

See Also

vuong in package pscl.

Examples

Run this code
data("tobin", package = "survival")
# selection double hurdle model
model110i <- mhurdle(durable ~ age |  quant | 0, tobin,  dist = "n")
# double-hurdle p-tobit
model011i <- mhurdle(durable ~ 0 |  quant | age, tobin,  dist = "n")
# Vuong test for strictly non-nested models
vuongtest(model011i, model110i)

Run the code above in your browser using DataLab