Learn R Programming

mhurdle (version 0.1-1)

vuongtest: Vuoung test for non-nested models

Description

The Vuong test is suitable to discriminate between two non-nested models.

Usage

vuongtest(x, y,
          type = c("non.nested", "nested", "overlapping"),
          hyp = FALSE)

Arguments

x
a first fitted model of class "mhurdle",
y
a second fitted model of class "mhurdle",
type
the kind of test to be computed,
hyp
a boolean, TRUE if one of the models is asumed to be the true model.

Value

  • an object of class "htest"

References

Vuong Q.H. (1989) Likelihood ratio tests for model selection and non-nested hypothesis, Econometrica, vol.57(2), pp.307-33.

See Also

vuong in package pscl.

Examples

Run this code
## dependent simple hurdle ptobit vs an
## independent double hurdle ptobit

data("tobin",package="survival")
dhi <- mhurdle(durable ~ 0 | age + quant | age + quant, tobin, 
             dist = "n", corr = FALSE)
dhs <- mhurdle(durable ~ 0 | age + quant | age + quant, tobin, 
              dist = "l", corr = FALSE)
vuongtest(dhi, dhs)

Run the code above in your browser using DataLab