Learn R Programming

mhurdle (version 0.1-2)

vuongtest: Vuoung test for non-nested models

Description

The Vuong test is suitable to discriminate between two non-nested models.

Usage

vuongtest(x, y,
          type = c("non-nested", "nested", "overlapping"),
          hyp = FALSE,
          variance = c("centered", "uncentered"),
          matrix = c("large", "reduced")
         )

Arguments

x
a first fitted model of class "mhurdle",
y
a second fitted model of class "mhurdle",
type
the kind of test to be computed,
hyp
a boolean, TRUE if one of the models is asumed to be the true model,
variance
the variance is estimated using the centered or uncentered expression,
matrix
the W matrix can be computed using the general expression large or the reduced matrix reduced (only relevant for the nested case),

Value

  • an object of class "htest"

References

Vuong Q.H. (1989) Likelihood ratio tests for model selection and non-nested hypothesis, Econometrica, vol.57(2), pp.307-33.

See Also

vuong in package pscl.

Examples

Run this code
# Vuong test for strictly non-nested models, triple hurdle vs double
# hurdle models
data("Comics", package = "mhurdle")
Comics$incu <- with(Comics, income / cu)
Comics$incum <- with(Comics, incu / mean(incu))
model5d <- mhurdle(comics ~ gender + educ + age |  log(incum) +
                   I(log(incum)^2) + I(log(incum)^3) + size | 0,
                   Comics, corr = "h1", dist = "n", method = 'bfgs')
model8d1 <- mhurdle(comics ~ gender + educ  |  log(incum) +
                    I(log(incum)^2) + I(log(incum)^3) + size | age,
                    Comics, corr = "h1", dist = "n", method = 'bfgs')
vuongtest(model5d, model8d1)

Run the code above in your browser using DataLab